@@ -1,8 +1,8 @@
 package cmd
 
 import (
+	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/cmdctx"
-	"github.com/superfly/flyctl/internal/client"
 
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/docstrings"
